@@ -20,7 +20,7 @@ import nested_diff.handlers
 
 __all__ = ['Differ', 'Iterator', 'Patcher', 'diff', 'patch']
 
-__version__ = '1.6.0'
+__version__ = '1.7.0'
 __author__ = 'Michael Samoglyadov'
 __license__ = 'Apache License, Version 2.0'
 __website__ = 'https://github.com/mr-mixas/Nested-Diff.py'
@@ -98,7 +98,7 @@ class Differ:
 
     default_differ = DEFAULT_HANDLER.diff
 
-    def __init__(
+    def __init__(  # noqa: PLR0913
         self,
         A=True,  # noqa: N803
         N=True,  # noqa: N803
