@@ -57,6 +57,7 @@ class App(nested_diff.cli.App):
             diff_opts['R'] = int(diff_opts['R'])
 
         differ = nested_diff.Differ(**diff_opts)
+        differ.set_handler(nested_diff.cli.YamlNodeHandler())
 
         if self.args.text_ctx >= 0:
             differ.set_handler(
@@ -65,7 +66,7 @@ class App(nested_diff.cli.App):
 
         return differ.diff(a, b)
 
-    def generate_diffs(self):
+    def generate_diffs(self):  # noqa: C901
         """Generate diffs."""
         a = None
         headers_enabled = False
@@ -73,9 +74,9 @@ class App(nested_diff.cli.App):
         if self.args.show:
             if len(self.args.files) > 1:
                 headers_enabled = True
-        elif len(self.args.files) < 2:
+        elif len(self.args.files) < 2:  # noqa: PLR2004
             self.argparser.error('Two or more arguments expected for diff')
-        elif len(self.args.files) > 2:
+        elif len(self.args.files) > 2:  # noqa: PLR2004
             headers_enabled = True
 
         for file_ in self.args.files:
@@ -253,7 +254,7 @@ class FormatterDumper(nested_diff.cli.Dumper):
 
     supported_fmts = ('term', 'text', 'html')
 
-    def __init__(
+    def __init__(  # noqa: PLR0913
         self,
         fmt,
         header=None,
@@ -286,6 +287,7 @@ class FormatterDumper(nested_diff.cli.Dumper):
 
         fmt_class = self.get_formatter_class(base_class, values=values)
         self.encoder = fmt_class(**self.get_opts(kwargs))
+        self.encoder.set_handler(nested_diff.cli.YamlNodeHandler())
 
         if header is None:
             if hasattr(self.encoder, 'get_page_header'):
